@@ -99,11 +99,10 @@ protected:
     KDESuPrivate::KCookie *m_cookie;
 
 private:
-    QByteArray commaSeparatedList(const QList<QByteArray> &lst);
-    void writeString(const QByteArray &str);
+    KDESU_NO_EXPORT void writeString(const QByteArray &str);
 
 protected:
-    explicit StubProcess(StubProcessPrivate &dd);
+    KDESU_NO_EXPORT explicit StubProcess(StubProcessPrivate &dd);
 
 private:
     Q_DECLARE_PRIVATE_D(PtyProcess::d, StubProcess)
