@@ -12,8 +12,8 @@
 
 #include "suprocess.h"
 
-#include "stubprocess_p.h"
 #include "kcookie_p.h"
+#include "stubprocess_p.h"
 #include <ksu_debug.h>
 
 #include <QFile>
@@ -26,11 +26,11 @@
 #include <kuser.h>
 
 #if defined(KDESU_USE_SUDO_DEFAULT)
-#  define DEFAULT_SUPER_USER_COMMAND QStringLiteral("sudo")
+#define DEFAULT_SUPER_USER_COMMAND QStringLiteral("sudo")
 #elif defined(KDESU_USE_DOAS_DEFAULT)
-#  define DEFAULT_SUPER_USER_COMMAND QStringLiteral("doas")
+#define DEFAULT_SUPER_USER_COMMAND QStringLiteral("doas")
 #else
-#  define DEFAULT_SUPER_USER_COMMAND QStringLiteral("su")
+#define DEFAULT_SUPER_USER_COMMAND QStringLiteral("su")
 #endif
 
 namespace KDESu
@@ -46,11 +46,9 @@ public:
 
 bool SuProcessPrivate::isPrivilegeEscalation() const
 {
-    return (superUserCommand == QLatin1String("sudo")
-            || superUserCommand == QLatin1String("doas"));
+    return (superUserCommand == QLatin1String("sudo") || superUserCommand == QLatin1String("doas"));
 }
 
-
 SuProcess::SuProcess(const QByteArray &user, const QByteArray &command)
     : StubProcess(*new SuProcessPrivate)
 {
@@ -101,8 +99,8 @@ int SuProcess::checkNeedPassword()
 }
 
 /*
-* Execute a command with su(1).
-*/
+ * Execute a command with su(1).
+ */
 int SuProcess::exec(const char *password, int check)
 {
     Q_D(SuProcess);
@@ -134,7 +132,7 @@ int SuProcess::exec(const char *password, int check)
     // Get the kdesu_stub and su command from a config file if set, used in test
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
     KConfigGroup group(config, "super-user-command");
-    const QString defaultPath = QStringLiteral(KDE_INSTALL_FULL_LIBEXECDIR_KF5) + QStringLiteral("/kdesu_stub");
+    const QString defaultPath = QStringLiteral(KDE_INSTALL_FULL_LIBEXECDIR_KF) + QStringLiteral("/kdesu_stub");
     const QString kdesuStubPath = group.readEntry("kdesu_stub_path", defaultPath);
     args += kdesuStubPath.toLocal8Bit();
     args += "-"; // krazy:exclude=doublequote_chars (QList, not QString)
@@ -145,6 +143,10 @@ int SuProcess::exec(const char *password, int check)
         return check ? SuNotFound : -1;
     }
 
+    // Turn echo off for conversion with kdesu_stub. Needs to be done before
+    // it's started so that sudo copies this option to its internal PTY.
+    enableLocalEcho(false);
+
     if (StubProcess::exec(command, args) < 0) {
         return check ? SuNotFound : -1;
     }
@@ -153,7 +155,8 @@ int SuProcess::exec(const char *password, int check)
 
     if (ret == error) {
         if (!check) {
-            qCCritical(KSU_LOG) << "[" << __FILE__ << ":" << __LINE__ << "] " << "Conversation with" << d->superUserCommand << "failed.";
+            qCCritical(KSU_LOG) << "[" << __FILE__ << ":" << __LINE__ << "] "
+                                << "Conversation with" << d->superUserCommand << "failed.";
         }
         return ret;
     }
@@ -164,9 +167,9 @@ int SuProcess::exec(const char *password, int check)
                 return ret;
             }
             if (kill(m_pid, SIGKILL) < 0) {
-                //FIXME SIGKILL doesn't work for sudo,
-                //why is this different from su?
-                //A: because sudo runs as root. Perhaps we could write a Ctrl+C to its stdin, instead?
+                // FIXME SIGKILL doesn't work for sudo,
+                // why is this different from su?
+                // A: because sudo runs as root. Perhaps we could write a Ctrl+C to its stdin, instead?
                 ret = error;
             } else {
                 int iret = waitForChild();
@@ -193,7 +196,8 @@ int SuProcess::exec(const char *password, int check)
     int iret = converseStub(check);
     if (iret < 0) {
         if (!check) {
-            qCCritical(KSU_LOG) << "[" << __FILE__ << ":" << __LINE__ << "] " << "Conversation with kdesu_stub failed.";
+            qCCritical(KSU_LOG) << "[" << __FILE__ << ":" << __LINE__ << "] "
+                                << "Conversation with kdesu_stub failed.";
         }
         return iret;
     } else if (iret == 1) {
@@ -212,14 +216,19 @@ int SuProcess::exec(const char *password, int check)
 }
 
 /*
-* Conversation with su: feed the password.
-* Return values: -1 = error, 0 = ok, 1 = kill me, 2 not authorized
-*/
+ * Conversation with su: feed the password.
+ * Return values: -1 = error, 0 = ok, 1 = kill me, 2 not authorized
+ */
 int SuProcess::converseSU(const char *password)
 {
-    enum { WaitForPrompt, CheckStar, HandleStub } state = WaitForPrompt;
+    enum {
+        WaitForPrompt,
+        CheckStar,
+        HandleStub,
+    } state = WaitForPrompt;
     int colon;
-    unsigned i, j;
+    unsigned i;
+    unsigned j;
 
     QByteArray line;
     while (true) {
@@ -248,7 +257,8 @@ int SuProcess::converseSU(const char *password)
             // Match "Password: " with the regex ^[^:]+:[\w]*$.
             for (i = 0, j = 0, colon = 0; i < len; ++i) {
                 if (line[i] == ':') {
-                    j = i; colon++;
+                    j = i;
+                    colon++;
                     continue;
                 }
                 if (!isspace(line[i])) {
@@ -275,11 +285,11 @@ int SuProcess::converseSU(const char *password)
                 state = HandleStub;
                 break;
             }
-            const uint len = line.length();
-            for (i = 0; i < len; ++i) {
-                if (s[i] != '*') {
-                    return error;
-                }
+            const bool starCond = std::any_of(s.cbegin(), s.cend(), [](const char c) {
+                return c != '*';
+            });
+            if (starCond) {
+                return error;
             }
             state = HandleStub;
             break;
